<?php
/**
 * VW Lawyer Attorney Theme Customizer
 *
 * @package VW Lawyer Attorney
 */
/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_lawyer_attorney_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_lawyer_attorney_custom_controls' );

function vw_lawyer_attorney_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; $wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'vw_lawyer_attorney_customize_partial_blogname', 
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'vw_lawyer_attorney_customize_partial_blogdescription', 
	));

	//add home page setting pannel
	$VWLawyerAttorneyParentPanel = new VW_Lawyer_Attorney_WP_Customize_Panel( $wp_customize, 'vw_lawyer_attorney_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => 'VW Settings',
		'priority' => 10,
	));

	$wp_customize->add_section( 'vw_lawyer_attorney_left_right', array(
    	'title'      => __( 'General Settings', 'vw-lawyer-attorney' ),
		'priority'   => 30,
		'panel' => 'vw_lawyer_attorney_panel_id'
	) );

	$wp_customize->add_setting('vw_lawyer_attorney_width_option',array(
        'default' => __('Full Width','vw-lawyer-attorney'),
        'sanitize_callback' => 'vw_lawyer_attorney_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Lawyer_Attorney_Image_Radio_Control($wp_customize, 'vw_lawyer_attorney_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-lawyer-attorney'),
        'description' => __('Here you can change the width layout of Website.','vw-lawyer-attorney'),
        'section' => 'vw_lawyer_attorney_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_lawyer_attorney_theme_options',array(
        'default' => __('Right Sidebar','vw-lawyer-attorney'),
        'sanitize_callback' => 'vw_lawyer_attorney_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_lawyer_attorney_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-lawyer-attorney'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-lawyer-attorney'),
        'section' => 'vw_lawyer_attorney_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-lawyer-attorney'),
            'Right Sidebar' => __('Right Sidebar','vw-lawyer-attorney'),
            'One Column' => __('One Column','vw-lawyer-attorney'),
            'Three Columns' => __('Three Columns','vw-lawyer-attorney'),
            'Four Columns' => __('Four Columns','vw-lawyer-attorney'),
            'Grid Layout' => __('Grid Layout','vw-lawyer-attorney')
        ),
	));

	$wp_customize->add_setting('vw_lawyer_attorney_page_layout',array(
        'default' => __('One Column','vw-lawyer-attorney'),
        'sanitize_callback' => 'vw_lawyer_attorney_sanitize_choices'
	));
	$wp_customize->add_control('vw_lawyer_attorney_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-lawyer-attorney'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-lawyer-attorney'),
        'section' => 'vw_lawyer_attorney_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-lawyer-attorney'),
            'Right Sidebar' => __('Right Sidebar','vw-lawyer-attorney'),
            'One Column' => __('One Column','vw-lawyer-attorney')
        ),
	) );

	//Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'vw_lawyer_attorney_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_lawyer_attorney_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Lawyer_Attorney_Toggle_Switch_Custom_Control( $wp_customize, 'vw_lawyer_attorney_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','vw-lawyer-attorney' ),
		'section' => 'vw_lawyer_attorney_left_right'
    )));

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'vw_lawyer_attorney_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_lawyer_attorney_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Lawyer_Attorney_Toggle_Switch_Custom_Control( $wp_customize, 'vw_lawyer_attorney_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','vw-lawyer-attorney' ),
		'section' => 'vw_lawyer_attorney_left_right'
    )));

	//Pre-Loader
	$wp_customize->add_setting( 'vw_lawyer_attorney_loader_enable',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_lawyer_attorney_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Lawyer_Attorney_Toggle_Switch_Custom_Control( $wp_customize, 'vw_lawyer_attorney_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','vw-lawyer-attorney' ),
        'section' => 'vw_lawyer_attorney_left_right'
    )));

    $wp_customize->add_setting('vw_lawyer_attorney_loader_icon',array(
        'default' => __('Two Way','vw-lawyer-attorney'),
        'sanitize_callback' => 'vw_lawyer_attorney_sanitize_choices'
	));
	$wp_customize->add_control('vw_lawyer_attorney_loader_icon',array(
        'type' => 'select',
        'label' => __('Pre-Loader Type','vw-lawyer-attorney'),
        'section' => 'vw_lawyer_attorney_left_right',
        'choices' => array(
            'Two Way' => __('Two Way','vw-lawyer-attorney'),
            'Dots' => __('Dots','vw-lawyer-attorney'),
            'Rotate' => __('Rotate','vw-lawyer-attorney')
        ),
	) );
	
	//Top Bar(topbar)
	$wp_customize->add_section('vw_lawyer_attorney_contact',array(
		'title'	=> __('Top Bar Settings','vw-lawyer-attorney'),
		'description'	=> __('Add contact us here','vw-lawyer-attorney'),
		'priority'	=> null,
		'panel' => 'vw_lawyer_attorney_panel_id',
	));

	$wp_customize->add_setting('vw_lawyer_attorney_topbar_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_lawyer_attorney_topbar_padding_top_bottom',array(
		'label'	=> __('Topbar Padding Top Bottom','vw-lawyer-attorney'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-lawyer-attorney'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-lawyer-attorney' ),
        ),
		'section'=> 'vw_lawyer_attorney_contact',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_lawyer_attorney_search_hide_show',
       array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_lawyer_attorney_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Lawyer_Attorney_Toggle_Switch_Custom_Control( $wp_customize, 'vw_lawyer_attorney_search_hide_show',
       array(
          'label' => esc_html__( 'Show / Hide Search','vw-lawyer-attorney' ),
          'section' => 'vw_lawyer_attorney_contact'
    )));

    $wp_customize->add_setting('vw_lawyer_attorney_search_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_lawyer_attorney_search_font_size',array(
		'label'	=> __('Search Font Size','vw-lawyer-attorney'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-lawyer-attorney'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-lawyer-attorney' ),
        ),
		'section'=> 'vw_lawyer_attorney_contact',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_lawyer_attorney_search_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_lawyer_attorney_search_padding_top_bottom',array(
		'label'	=> __('Search Padding Top Bottom','vw-lawyer-attorney'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-lawyer-attorney'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-lawyer-attorney' ),
        ),
		'section'=> 'vw_lawyer_attorney_contact',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_lawyer_attorney_search_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_lawyer_attorney_search_padding_left_right',array(
		'label'	=> __('Search Padding Left Right','vw-lawyer-attorney'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-lawyer-attorney'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-lawyer-attorney' ),
        ),
		'section'=> 'vw_lawyer_attorney_contact',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_lawyer_attorney_search_border_radius', array(
		'default'              => "",
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_lawyer_attorney_search_border_radius', array(
		'label'       => esc_html__( 'Search Border Radius','vw-lawyer-attorney' ),
		'section'     => 'vw_lawyer_attorney_contact',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

    //Sticky Header
	$wp_customize->add_setting( 'vw_lawyer_attorney_sticky_header',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_lawyer_attorney_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Lawyer_Attorney_Toggle_Switch_Custom_Control( $wp_customize, 'vw_lawyer_attorney_sticky_header',array(
        'label' => esc_html__( 'Sticky Header','vw-lawyer-attorney' ),
        'section' => 'vw_lawyer_attorney_contact'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial(
		'vw_lawyer_attorney_call', array( 
			'selector' => '.contact p.diff-lay', 
			'render_callback' => 'vw_lawyer_attorney_customize_partial_vw_lawyer_attorney_call', 
	));

	$wp_customize->add_setting('vw_lawyer_attorney_call',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('vw_lawyer_attorney_call',array(
		'label'	=> __('Phone Number','vw-lawyer-attorney'),
		'section'	=> 'vw_lawyer_attorney_contact',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_lawyer_attorney_call1',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('vw_lawyer_attorney_call1',array(
		'label'	=> __('Email Address','vw-lawyer-attorney'),
		'section'	=> 'vw_lawyer_attorney_contact',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_lawyer_attorney_location',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('vw_lawyer_attorney_location',array(
		'label'	=> __('Address 1','vw-lawyer-attorney'),
		'section'	=> 'vw_lawyer_attorney_contact',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_lawyer_attorney_location1',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('vw_lawyer_attorney_location1',array(
		'label'	=> __('Address 2','vw-lawyer-attorney'),
		'section'	=> 'vw_lawyer_attorney_contact',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_lawyer_attorney_time',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('vw_lawyer_attorney_time',array(
		'label'	=> __('Opening time.','vw-lawyer-attorney'),
		'section'	=> 'vw_lawyer_attorney_contact',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_lawyer_attorney_time1',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('vw_lawyer_attorney_time1',array(
		'label'	=> __('Closing Time','vw-lawyer-attorney'),
		'section'	=> 'vw_lawyer_attorney_contact',
		'type'		=> 'text'
	));
	
	//home page slider
    $wp_customize->add_section( 'vw_lawyer_attorney_slidersettings' , array(
      'title'      => __( 'Slider Settings', 'vw-lawyer-attorney' ),
      'priority'   => null,
      'panel' => 'vw_lawyer_attorney_panel_id'
    ) );

    $wp_customize->add_setting( 'vw_lawyer_attorney_slider_hide_show',
       array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_lawyer_attorney_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Lawyer_Attorney_Toggle_Switch_Custom_Control( $wp_customize, 'vw_lawyer_attorney_slider_hide_show',
       array(
          'label' => esc_html__( 'Show / Hide Slider','vw-lawyer-attorney' ),
          'section' => 'vw_lawyer_attorney_slidersettings'
    )));

    //Selective Refresh
    $wp_customize->selective_refresh->add_partial(
    	'vw_lawyer_attorney_slider_hide_show',array(
			'selector'        => '.slider .inner_carousel h1',
			'render_callback' => 'vw_lawyer_attorney_customize_partial_vw_lawyer_attorney_slider_hide_show',
	));

    for ( $count = 1; $count <= 4; $count++ ) {

	    // Add color scheme setting and control.
	    $wp_customize->add_setting( 'vw_lawyer_attorney_slider_page' . $count, array(
	      'default'           => '',
	      'sanitize_callback' => 'vw_lawyer_attorney_sanitize_dropdown_pages'
	    ) );
	    $wp_customize->add_control( 'vw_lawyer_attorney_slider_page' . $count, array(
	      'label'    => __( 'Select Slide Image Page', 'vw-lawyer-attorney' ),
	      'description' => __('Slider image size (1500 x 765)','vw-lawyer-attorney'),
	      'section'  => 'vw_lawyer_attorney_slidersettings',
	      'type'     => 'dropdown-pages'
	    ) );
	    
    }

    //content layout
	$wp_customize->add_setting('vw_lawyer_attorney_slider_content_option',array(
        'default' => __('Left','vw-lawyer-attorney'),
        'sanitize_callback' => 'vw_lawyer_attorney_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Lawyer_Attorney_Image_Radio_Control($wp_customize, 'vw_lawyer_attorney_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','vw-lawyer-attorney'),
        'section' => 'vw_lawyer_attorney_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'vw_lawyer_attorney_slider_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_lawyer_attorney_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-lawyer-attorney' ),
		'section'     => 'vw_lawyer_attorney_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_lawyer_attorney_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('vw_lawyer_attorney_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'vw_lawyer_attorney_sanitize_choices'
	));

	$wp_customize->add_control( 'vw_lawyer_attorney_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','vw-lawyer-attorney' ),
	'section'     => 'vw_lawyer_attorney_slidersettings',
	'type'        => 'select',
	'settings'    => 'vw_lawyer_attorney_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','vw-lawyer-attorney'),
      '0.1' =>  esc_attr('0.1','vw-lawyer-attorney'),
      '0.2' =>  esc_attr('0.2','vw-lawyer-attorney'),
      '0.3' =>  esc_attr('0.3','vw-lawyer-attorney'),
      '0.4' =>  esc_attr('0.4','vw-lawyer-attorney'),
      '0.5' =>  esc_attr('0.5','vw-lawyer-attorney'),
      '0.6' =>  esc_attr('0.6','vw-lawyer-attorney'),
      '0.7' =>  esc_attr('0.7','vw-lawyer-attorney'),
      '0.8' =>  esc_attr('0.8','vw-lawyer-attorney'),
      '0.9' =>  esc_attr('0.9','vw-lawyer-attorney')
	),
	));
    
	//About
	$wp_customize->add_section('vw_lawyer_attorney_about1',array(
		'title'	=> __('About Section','vw-lawyer-attorney'),
		'description'	=> __('Add About sections below.','vw-lawyer-attorney'),
		'panel' => 'vw_lawyer_attorney_panel_id',
	));

	$args = array('numberposts' => -1);
	$post_list = get_posts($args);
	$posts[]='Select';	
	foreach($post_list as $post){
		$posts[$post->post_title] = $post->post_title;
	}
	
	$wp_customize->add_setting('vw_lawyer_attorney_about_setting',array(
		'sanitize_callback' => 'sanitize_text_field',
	));

	$wp_customize->add_control('vw_lawyer_attorney_about_setting',array(
		'type'    => 'select',
		'choices' => $posts,
		'label' => __('Select post','vw-lawyer-attorney'),
		'section' => 'vw_lawyer_attorney_about1',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_lawyer_attorney_about_name', array( 
		'selector' => '.about .testbutton a', 
		'render_callback' => 'vw_lawyer_attorney_customize_partial_vw_lawyer_attorney_about_name',
	));

	$wp_customize->add_setting('vw_lawyer_attorney_about_name',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	

	$wp_customize->add_control('vw_lawyer_attorney_about_name',array(
		'label'	=> __('Discover More text','vw-lawyer-attorney'),
		'section'	=> 'vw_lawyer_attorney_about1',
		'setting'	=> 'vw_lawyer_attorney_about_name',
		'type'		=> 'text'
	));

	//About excerpt
	$wp_customize->add_setting( 'vw_lawyer_attorney_about_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_lawyer_attorney_about_excerpt_number', array(
		'label'       => esc_html__( 'About Excerpt length','vw-lawyer-attorney' ),
		'section'     => 'vw_lawyer_attorney_about1',
		'type'        => 'range',
		'settings'    => 'vw_lawyer_attorney_about_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Why Choose us
	$wp_customize->add_section('vw_lawyer_attorney_amenities_section',array(
		'title'	=> __('Why Choose Us','vw-lawyer-attorney'),
		'description'	=> '',
		'priority'	=> null,
		'panel' => 'vw_lawyer_attorney_panel_id',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_lawyer_attorney_main_title', array( 
		'selector' => '.choose h3', 
		'render_callback' => 'vw_lawyer_attorney_customize_partial_vw_lawyer_attorney_main_title',
	));
	
	$wp_customize->add_setting('vw_lawyer_attorney_main_title',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field',
	));

	$wp_customize->add_control('vw_lawyer_attorney_main_title',array(
		'label'	=> __('Title','vw-lawyer-attorney'),
		'section'	=> 'vw_lawyer_attorney_amenities_section',
		'type'	=> 'text'
	));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cats[]= 'select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cats[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_lawyer_attorney_blogcategory_setting',array(
		'default'	=> 'select',
		'sanitize_callback' => 'vw_lawyer_attorney_sanitize_choices',
	));

	$wp_customize->add_control('vw_lawyer_attorney_blogcategory_setting',array(
		'type'    => 'select',
		'choices' => $cats,
		'label' => __('Select Category to display Latest Post','vw-lawyer-attorney'),
		'section' => 'vw_lawyer_attorney_amenities_section',
	));

	//About excerpt
	$wp_customize->add_setting( 'vw_lawyer_attorney_choose_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_lawyer_attorney_choose_excerpt_number', array(
		'label'       => esc_html__( 'About Excerpt length','vw-lawyer-attorney' ),
		'section'     => 'vw_lawyer_attorney_amenities_section',
		'type'        => 'range',
		'settings'    => 'vw_lawyer_attorney_choose_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog Post
	$wp_customize->add_panel( $VWLawyerAttorneyParentPanel );

	$BlogPostParentPanel = new VW_Lawyer_Attorney_WP_Customize_Panel( $wp_customize, 'blog_post_parent_panel', array(
		'title' => __( 'Blog Post Settings', 'vw-lawyer-attorney' ),
		'panel' => 'vw_lawyer_attorney_panel_id',
	));

	$wp_customize->add_panel( $BlogPostParentPanel );

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'vw_lawyer_attorney_post_settings', array(
		'title' => __( 'Post Settings', 'vw-lawyer-attorney' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial(
		'vw_lawyer_attorney_toggle_postdate', array( 
			'selector' => '.postbox h2 a', 
			'render_callback' => 'vw_lawyer_attorney_customize_partial_vw_lawyer_attorney_toggle_postdate', 
	));

	$wp_customize->add_setting( 'vw_lawyer_attorney_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_lawyer_attorney_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Lawyer_Attorney_Toggle_Switch_Custom_Control( $wp_customize, 'vw_lawyer_attorney_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-lawyer-attorney' ),
        'section' => 'vw_lawyer_attorney_post_settings'
    )));

    $wp_customize->add_setting( 'vw_lawyer_attorney_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_lawyer_attorney_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Lawyer_Attorney_Toggle_Switch_Custom_Control( $wp_customize, 'vw_lawyer_attorney_toggle_author',array(
		'label' => esc_html__( 'Author','vw-lawyer-attorney' ),
		'section' => 'vw_lawyer_attorney_post_settings'
    )));

    $wp_customize->add_setting( 'vw_lawyer_attorney_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_lawyer_attorney_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Lawyer_Attorney_Toggle_Switch_Custom_Control( $wp_customize, 'vw_lawyer_attorney_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-lawyer-attorney' ),
		'section' => 'vw_lawyer_attorney_post_settings'
    )));

    $wp_customize->add_setting( 'vw_lawyer_attorney_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_lawyer_attorney_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Lawyer_Attorney_Toggle_Switch_Custom_Control( $wp_customize, 'vw_lawyer_attorney_toggle_tags', array(
		'label' => esc_html__( 'Tags','vw-lawyer-attorney' ),
		'section' => 'vw_lawyer_attorney_post_settings'
    )));

    $wp_customize->add_setting( 'vw_lawyer_attorney_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_lawyer_attorney_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-lawyer-attorney' ),
		'section'     => 'vw_lawyer_attorney_post_settings',
		'type'        => 'range',
		'settings'    => 'vw_lawyer_attorney_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog layout
    $wp_customize->add_setting('vw_lawyer_attorney_blog_layout_option',array(
        'default' => __('Default','vw-lawyer-attorney'),
        'sanitize_callback' => 'vw_lawyer_attorney_sanitize_choices'
    ));
    $wp_customize->add_control(new VW_Lawyer_Attorney_Image_Radio_Control($wp_customize, 'vw_lawyer_attorney_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Layouts','vw-lawyer-attorney'),
        'section' => 'vw_lawyer_attorney_post_settings',
        'choices' => array(
            'Default' => get_template_directory_uri().'/images/blog-layout1.png',
            'Center' => get_template_directory_uri().'/images/blog-layout2.png',
            'Left' => get_template_directory_uri().'/images/blog-layout3.png',
    ))));

    $wp_customize->add_setting('vw_lawyer_attorney_excerpt_settings',array(
        'default' => __('Excerpt','vw-lawyer-attorney'),
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_lawyer_attorney_sanitize_choices'
	));
	$wp_customize->add_control('vw_lawyer_attorney_excerpt_settings',array(
        'type' => 'select',
        'label' => __('Post Content','vw-lawyer-attorney'),
        'section' => 'vw_lawyer_attorney_post_settings',
        'choices' => array(
        	'Content' => __('Content','vw-lawyer-attorney'),
            'Excerpt' => __('Excerpt','vw-lawyer-attorney'),
            'No Content' => __('No Content','vw-lawyer-attorney')
        ),
	) );

	$wp_customize->add_setting('vw_lawyer_attorney_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_lawyer_attorney_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','vw-lawyer-attorney'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'vw-lawyer-attorney' ),
        ),
		'section'=> 'vw_lawyer_attorney_post_settings',
		'type'=> 'text'
	));

    // Button Settings
	$wp_customize->add_section( 'vw_lawyer_attorney_button_settings', array(
		'title' => __( 'Button Settings', 'vw-lawyer-attorney' ),
		'panel' => 'blog_post_parent_panel',
	));

	$wp_customize->add_setting('vw_lawyer_attorney_button_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_lawyer_attorney_button_padding_top_bottom',array(
		'label'	=> __('Padding Top Bottom','vw-lawyer-attorney'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-lawyer-attorney'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-lawyer-attorney' ),
        ),
		'section'=> 'vw_lawyer_attorney_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_lawyer_attorney_button_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_lawyer_attorney_button_padding_left_right',array(
		'label'	=> __('Padding Left Right','vw-lawyer-attorney'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-lawyer-attorney'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-lawyer-attorney' ),
        ),
		'section'=> 'vw_lawyer_attorney_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_lawyer_attorney_button_border_radius', array(
		'default'              => '',
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_lawyer_attorney_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','vw-lawyer-attorney' ),
		'section'     => 'vw_lawyer_attorney_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_lawyer_attorney_button_text', array( 
			'selector' => '.postbox .testbutton a', 
			'render_callback' => 'vw_lawyer_attorney_customize_partial_vw_lawyer_attorney_button_text', 
	));

	 $wp_customize->add_setting('vw_lawyer_attorney_button_text',array(
		'default'=> 'Read Full',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_lawyer_attorney_button_text',array(
		'label'	=> __('Add Button Text','vw-lawyer-attorney'),
		'input_attrs' => array(
            'placeholder' => __( 'Read Full', 'vw-lawyer-attorney' ),
        ),
		'section'=> 'vw_lawyer_attorney_button_settings',
		'type'=> 'text'
	));

	// Related Post Settings
	$wp_customize->add_section( 'vw_lawyer_attorney_related_posts_settings', array(
		'title' => __( 'Related Posts Settings', 'vw-lawyer-attorney' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_lawyer_attorney_related_post_title', array( 
			'selector' => '.related-post h3', 
			'render_callback' => 'vw_lawyer_attorney_customize_partial_vw_lawyer_attorney_related_post_title', 
	));

    $wp_customize->add_setting( 'vw_lawyer_attorney_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_lawyer_attorney_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Lawyer_Attorney_Toggle_Switch_Custom_Control( $wp_customize, 'vw_lawyer_attorney_related_post',array(
		'label' => esc_html__( 'Related Post','vw-lawyer-attorney' ),
		'section' => 'vw_lawyer_attorney_related_posts_settings'
    )));

    $wp_customize->add_setting('vw_lawyer_attorney_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_lawyer_attorney_related_post_title',array(
		'label'	=> __('Add Related Post Title','vw-lawyer-attorney'),
		'input_attrs' => array(
            'placeholder' => __( 'Related Post', 'vw-lawyer-attorney' ),
        ),
		'section'=> 'vw_lawyer_attorney_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('vw_lawyer_attorney_related_posts_count',array(
		'default'=> '3',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_lawyer_attorney_related_posts_count',array(
		'label'	=> __('Add Related Post Count','vw-lawyer-attorney'),
		'input_attrs' => array(
            'placeholder' => __( '3', 'vw-lawyer-attorney' ),
        ),
		'section'=> 'vw_lawyer_attorney_related_posts_settings',
		'type'=> 'number'
	));

    //404 Page Setting
	$wp_customize->add_section('vw_lawyer_attorney_404_page',array(
		'title'	=> __('404 Page Settings','vw-lawyer-attorney'),
		'panel' => 'vw_lawyer_attorney_panel_id',
	));	

	$wp_customize->add_setting('vw_lawyer_attorney_404_page_title',array(
		'default'=> '404 Not Found',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_lawyer_attorney_404_page_title',array(
		'label'	=> __('Add Title','vw-lawyer-attorney'),
		'input_attrs' => array(
            'placeholder' => __( '404 Not Found', 'vw-lawyer-attorney' ),
        ),
		'section'=> 'vw_lawyer_attorney_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_lawyer_attorney_404_page_content',array(
		'default'=> 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_lawyer_attorney_404_page_content',array(
		'label'	=> __('Add Text','vw-lawyer-attorney'),
		'input_attrs' => array(
            'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'vw-lawyer-attorney' ),
        ),
		'section'=> 'vw_lawyer_attorney_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_lawyer_attorney_404_page_button_text',array(
		'default'=> 'Return to Home Page',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_lawyer_attorney_404_page_button_text',array(
		'label'	=> __('Add Button Text','vw-lawyer-attorney'),
		'input_attrs' => array(
            'placeholder' => __( 'Return to Home Page', 'vw-lawyer-attorney' ),
        ),
		'section'=> 'vw_lawyer_attorney_404_page',
		'type'=> 'text'
	));

	//Responsive Media Settings
	$wp_customize->add_section('vw_lawyer_attorney_responsive_media',array(
		'title'	=> __('Responsive Media','vw-lawyer-attorney'),
		'panel' => 'vw_lawyer_attorney_panel_id',
	));

    $wp_customize->add_setting( 'vw_lawyer_attorney_stickyheader_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_lawyer_attorney_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Lawyer_Attorney_Toggle_Switch_Custom_Control( $wp_customize, 'vw_lawyer_attorney_stickyheader_hide_show',array(
          'label' => esc_html__( 'Sticky Header','vw-lawyer-attorney' ),
          'section' => 'vw_lawyer_attorney_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_lawyer_attorney_resp_slider_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_lawyer_attorney_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Lawyer_Attorney_Toggle_Switch_Custom_Control( $wp_customize, 'vw_lawyer_attorney_resp_slider_hide_show',array(
          'label' => esc_html__( 'Show / Hide Slider','vw-lawyer-attorney' ),
          'section' => 'vw_lawyer_attorney_responsive_media'
    )));

	$wp_customize->add_setting( 'vw_lawyer_attorney_metabox_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_lawyer_attorney_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Lawyer_Attorney_Toggle_Switch_Custom_Control( $wp_customize, 'vw_lawyer_attorney_metabox_hide_show',array(
          'label' => esc_html__( 'Show / Hide Metabox','vw-lawyer-attorney' ),
          'section' => 'vw_lawyer_attorney_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_lawyer_attorney_sidebar_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_lawyer_attorney_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Lawyer_Attorney_Toggle_Switch_Custom_Control( $wp_customize, 'vw_lawyer_attorney_sidebar_hide_show',array(
          'label' => esc_html__( 'Show / Hide Sidebar','vw-lawyer-attorney' ),
          'section' => 'vw_lawyer_attorney_responsive_media'
    )));

    $wp_customize->add_setting('vw_lawyer_attorney_res_open_menu_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Lawyer_Attorney_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_lawyer_attorney_res_open_menu_icon',array(
		'label'	=> __('Add Open Menu Icon','vw-lawyer-attorney'),
		'transport' => 'refresh',
		'section'	=> 'vw_lawyer_attorney_responsive_media',
		'setting'	=> 'vw_lawyer_attorney_res_open_menu_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_lawyer_attorney_res_close_menu_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Lawyer_Attorney_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_lawyer_attorney_res_close_menu_icon',array(
		'label'	=> __('Add Close Menu Icon','vw-lawyer-attorney'),
		'transport' => 'refresh',
		'section'	=> 'vw_lawyer_attorney_responsive_media',
		'setting'	=> 'vw_lawyer_attorney_res_close_menu_icon',
		'type'		=> 'icon'
	)));

	//Content Creation
	$wp_customize->add_section( 'vw_lawyer_attorney_content_section' , array(
    	'title' => __( 'Customize Home Page Settings', 'vw-lawyer-attorney' ),
		'priority' => null,
		'panel' => 'vw_lawyer_attorney_panel_id'
	) );

	$wp_customize->add_setting('vw_lawyer_attorney_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new VW_Lawyer_Attorney_Content_Creation( $wp_customize, 'vw_lawyer_attorney_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','vw-lawyer-attorney' ),
		),
		'section' => 'vw_lawyer_attorney_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'vw-lawyer-attorney' ),
	) ) );

	//footer
	$wp_customize->add_section('vw_lawyer_attorney_footer_section',array(
		'title'	=> __('Footer Text','vw-lawyer-attorney'),
		'description'	=> __('Add some text for footer like copyright etc.','vw-lawyer-attorney'),
		'priority'	=> null,
		'panel' => 'vw_lawyer_attorney_panel_id',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial(
		'vw_lawyer_attorney_footer_copy', array( 
			'selector' => '.footer-2 .copyright p', 
		'render_callback' => 'vw_lawyer_attorney_customize_partial_vw_lawyer_attorney_footer_copy', 
	));
	
	$wp_customize->add_setting('vw_lawyer_attorney_footer_copy',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field',
	));	
	$wp_customize->add_control('vw_lawyer_attorney_footer_copy',array(
		'label'	=> __('Copyright Text','vw-lawyer-attorney'),
		'section'	=> 'vw_lawyer_attorney_footer_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_lawyer_attorney_copyright_alingment',array(
        'default' => __('center','vw-lawyer-attorney'),
        'sanitize_callback' => 'vw_lawyer_attorney_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Lawyer_Attorney_Image_Radio_Control($wp_customize, 'vw_lawyer_attorney_copyright_alingment', array(
        'type' => 'select',
        'label' => __('Copyright Alignment','vw-lawyer-attorney'),
        'section' => 'vw_lawyer_attorney_footer_section',
        'settings' => 'vw_lawyer_attorney_copyright_alingment',
        'choices' => array(
            'left' => get_template_directory_uri().'/images/copyright1.png',
            'center' => get_template_directory_uri().'/images/copyright2.png',
            'right' => get_template_directory_uri().'/images/copyright3.png'
    ))));

    $wp_customize->add_setting('vw_lawyer_attorney_copyright_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_lawyer_attorney_copyright_padding_top_bottom',array(
		'label'	=> __('Copyright Padding Top Bottom','vw-lawyer-attorney'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-lawyer-attorney'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-lawyer-attorney' ),
        ),
		'section'=> 'vw_lawyer_attorney_footer_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_lawyer_attorney_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_lawyer_attorney_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Lawyer_Attorney_Toggle_Switch_Custom_Control( $wp_customize, 'vw_lawyer_attorney_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-lawyer-attorney' ),
      	'section' => 'vw_lawyer_attorney_footer_section'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial(
		'vw_lawyer_attorney_scroll_top_icon', array( 
			'selector' => '.scrollup i', 
			'render_callback' => 'vw_lawyer_attorney_customize_partial_vw_lawyer_attorney_scroll_top_icon', 
	));

    $wp_customize->add_setting('vw_lawyer_attorney_scroll_top_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Lawyer_Attorney_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_lawyer_attorney_scroll_top_icon',array(
		'label'	=> __('Add Scroll to Top Icon','vw-lawyer-attorney'),
		'transport' => 'refresh',
		'section'	=> 'vw_lawyer_attorney_footer_section',
		'setting'	=> 'vw_lawyer_attorney_scroll_top_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_lawyer_attorney_scroll_top_alignment',array(
        'default' => __('Right','vw-lawyer-attorney'),
        'sanitize_callback' => 'vw_lawyer_attorney_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Lawyer_Attorney_Image_Radio_Control($wp_customize, 'vw_lawyer_attorney_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-lawyer-attorney'),
        'section' => 'vw_lawyer_attorney_footer_section',
        'settings' => 'vw_lawyer_attorney_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/images/layout1.png',
            'Center' => get_template_directory_uri().'/images/layout2.png',
            'Right' => get_template_directory_uri().'/images/layout3.png'
    ))));
	/** home page setions end here**/	

	// Has to be at the top
	$wp_customize->register_panel_type( 'VW_Lawyer_Attorney_WP_Customize_Panel' );
	$wp_customize->register_section_type( 'VW_Lawyer_Attorney_WP_Customize_Section' );
}
add_action( 'customize_register', 'vw_lawyer_attorney_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo-resizer.php' );

if ( class_exists( 'WP_Customize_Panel' ) ) {

  class VW_Lawyer_Attorney_WP_Customize_Panel extends WP_Customize_Panel {

    public $panel;
    public $type = 'vw_lawyer_attorney_panel';
    public function json() {

      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'type', 'panel', ) );
      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
      $array['content'] = $this->get_content();
      $array['active'] = $this->active();
      $array['instanceNumber'] = $this->instance_number;
      return $array;
    }
  }
}

if ( class_exists( 'WP_Customize_Section' ) ) {
  class VW_Lawyer_Attorney_WP_Customize_Section extends WP_Customize_Section {
  	
    public $section;
    public $type = 'vw_lawyer_attorney_section';
    public function json() {

      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'panel', 'type', 'description_hidden', 'section', ) );
      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
      $array['content'] = $this->get_content();
      $array['active'] = $this->active();
      $array['instanceNumber'] = $this->instance_number;

      if ( $this->panel ) {
        $array['customizeAction'] = sprintf( 'Customizing &#9656; %s', esc_html( $this->manager->get_panel( $this->panel )->title ) );
      } else {
        $array['customizeAction'] = 'Customizing';
      }
      return $array;
    }
  }
}

// Enqueue our scripts and styles
function vw_lawyer_attorney_customize_controls_scripts() {
  wp_enqueue_script( 'customizer-controls', get_theme_file_uri( '/js/customizer-controls.js' ), array(), '1.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'vw_lawyer_attorney_customize_controls_scripts' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Lawyer_Attorney_customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Lawyer_Attorney_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Lawyer_Attorney_Customize_Section_Pro($manager,
			'example_1',array(
			'priority'   => 1,
			'title'    => esc_html__( 'VW Lawyer Pro', 'vw-lawyer-attorney' ),
			'pro_text' => esc_html__( 'Upgarde Pro','vw-lawyer-attorney' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/premium-lawyer-wordpress-theme/')
		)));

		// Register sections.
		$manager->add_section(new VW_Lawyer_Attorney_Customize_Section_Pro($manager,
			'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'Documentation', 'vw-lawyer-attorney' ),
			'pro_text' => esc_html__( 'Docs', 'vw-lawyer-attorney' ),
			'pro_url'  => admin_url( 'themes.php?page=vw_lawyer_attorney_guide' )
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-lawyer-attorney-customize-controls', trailingslashit( get_template_directory_uri() ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-lawyer-attorney-customize-controls', trailingslashit( get_template_directory_uri() ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_lawyer_Attorney_Customize::get_instance();